package App::ListUbuntuReleases;

our $DATE = '2015-09-22'; # DATE
our $VERSION = '0.06'; # VERSION

1;
# ABSTRACT: List Ubuntu releases (CLI)

__END__

=pod

=encoding UTF-8

=head1 NAME

App::ListUbuntuReleases - List Ubuntu releases (CLI)

=head1 VERSION

This document describes version 0.06 of App::ListUbuntuReleases (from Perl distribution App-ListUbuntuReleases), released on 2015-09-22.

=head1 DESCRIPTION

See the included script L<list-ubuntu-releases>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-ListUbuntuReleases>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-ListUbuntuReleases>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ListUbuntuReleases>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
